Dealer class

Constructors

Dealer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSession(SessionDetails details) → void
hasRegistration(String procedure) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveMessage(int sessionID, Message message) MessageWithRecipient
removeSession(int sid) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited